km3astro
========

.. image:: https://git.km3net.de/km3py/km3astro/badges/master/pipeline.svg
    :target: https://git.km3net.de/km3py/km3astro/pipelines

.. image:: https://git.km3net.de/km3py/km3astro/badges/master/coverage.svg
    :target: https://km3py.pages.km3net.de/km3astro/coverage

.. image:: https://git.km3net.de/examples/km3badges/-/raw/master/docs-latest-brightgreen.svg
    :target: https://km3py.pages.km3net.de/km3astro

About
-----

KM3Astro is a collection astronomy utils, like coordinate transformations.

Install
-------

This is developed on python >=3.5. Lower versions (especially py2)
might or might not work. Use ``pip`` to install the latest
version::

  pip install km3astro


Install the latest development version
~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~

To get the latest and greatest stable development version, use ``pip``
and the URL to the repository::

  pip install git+http://git.km3net.de/km3py/km3astro.git

or just clone the git repository and install via ``pip install .``
